@@ -1238,6 +1238,23 @@ def stop_check(loss,stop_criterion,stop_criterion_window):
     return (w[0]-w[-1])/w[0] < stop_criterion
 
 
+def print_performance_epoch(self):
+    for set in ['train', 'valid', 'test']:
+        y_test2 = np.vstack(self.test_pred.__dict__[set].y_test)
+        y_pred2 = np.vstack(self.test_pred.__dict__[set].y_pred)
+        print(set.capitalize() + " Accuracy = {:.2f}".format(
+            np.average(np.equal(np.argmax(y_pred2, 1), np.argmax(y_test2, 1)))), end=', ')
 
+    print('')
+
+    try:
+        for set in ['train', 'valid', 'test']:
+            print(
+                set.capitalize() + " AUC = {:.2f}".format(roc_auc_score(np.vstack(self.test_pred.__dict__[set].y_test),
+                                                                        np.vstack(self.test_pred.__dict__[set].y_pred))),
+                end=', ')
+        print('')
+    except:
+        pass
 
 
